@@ -123,6 +123,10 @@ class TestExocad(unittest.TestCase):
         self.assertEqual(order.elements[0].teeth[0].implant_system, 'medentika_preface-l_conid : PreFace_L9810-16R-1 : L9810-16R-1')
         self.assertEqual(order.elements[1].teeth[0].implant_system, None)
 
+        project = Path('tests/samples/exocad/EdgeCases/AbutmentAliasNotDetected')
+        _, _, _, _, _, order = exocad.parse(project)
+        self.assertEqual(order.elements[0].teeth[0].implant_system, 'medentika_preface-n_conid : PreFace_N9810-16R-1 : N9810-16R-1')
+
     def test_parse_complex_partial_framework(self):
         project = Path('tests/samples/exocad/EdgeCases/PartialFramework')
         found_dentalProject = next(project.glob('*.dental[pP]roject'), False)
