@@ -133,4 +133,37 @@ class Threeshape(unittest.TestCase):
         threeshape_file, order = threeshape.parse(Path('tests/samples/3shape/02_Krone/180148'))
 
         for element in order.elements:
-            self.assertIsNone(element.type)
\ No newline at end of file
+            self.assertIsNone(element.type)
+
+    def test_abutment_alias(self):
+        threeshape_file, order = threeshape.parse(Path('tests/samples/3shape/09_Abutment/180066'))
+
+        for element in order.elements:
+            for tooth in element.teeth:
+                if tooth.fdi == 46:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+                if tooth.fdi == 45:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+                if tooth.fdi == 14:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+                if tooth.fdi == 17:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+
+        
+        threeshape_file, order = threeshape.parse(Path('tests/samples/3shape/09_Abutment/180608'))
+
+        for element in order.elements:
+            for tooth in element.teeth:
+                if tooth.fdi == 14:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+                if tooth.fdi == 36:
+                    self.assertEqual(tooth.implant_system, 'Abutment_MEG_3.555_GH05')
+
+        threeshape_file, order = threeshape.parse(Path('tests/samples/3shape/09_Abutment/184819'))
+
+        for element in order.elements:
+            for tooth in element.teeth:
+                if tooth.fdi == 16:
+                    self.assertEqual(tooth.implant_system, 'BTI® 23.2 INTERNA UNIVERSAL_INPSPU0_65')
+                if tooth.fdi == 13:
+                    self.assertEqual(tooth.implant_system, 'BTI® 23.2 INTERNA UNIVERSAL_INPSPU0_65')
\ No newline at end of file
