@@ -4,7 +4,7 @@ from cad_parser.definitions import Tooth
 
 class TestTooth(unittest.TestCase):
     def test_constructor(self):
-        tooth = Tooth(1, 'A1', None, None, 'AnatomicCrown')
+        tooth = Tooth(fdi=1, color='A1', implant_system=None, implant_type=None, is_anatomical=None, type='AnatomicCrown')
 
         self.assertEqual(tooth.fdi, 1)
         self.assertEqual(tooth.color, 'A1')
